@@ -53,7 +53,10 @@ class HTTP(Session):
                 self.headers[i] = headers[i]
 
         log.debug("HTTP getting %r", url)
-        res = Session.request(self, method, url, verify=self.verify, *args, **kwargs)
+        try:
+            res = Session.request(self, method, url, verify=self.verify, *args, **kwargs)
+        except:
+            return None
         return res
 
     def split_header(self, headers):
@@ -96,9 +99,12 @@ def protocol_prio(streams, priolist):
 def select_quality(options, streams):
     high = 0
     if isinstance(options.quality, str):
-        quality = int(options.quality.split(",")[0])
-        if len(options.quality.split(",")) > 1:
-            high = int(options.quality.split(",")[1])
+        try:
+            quality = int(options.quality.split("-")[0])
+            if len(options.quality.split("-")) > 1:
+                high = int(options.quality.split("-")[1])
+        except ValueError:
+            raise error.UIException("Requested quality is invalid. use a number or range lowerNumber-higherNumber")
     else:
         quality = options.quality
     try:
